.. _filter-gff:

filter-gff - Filter GFF annotations
===================================

Overview
--------

.. automodule:: mgkit.workflow.filter_gff


Options
-------

.. click:: mgkit.workflow.filter_gff:main
   :prog: filter-gff
   :show-nested:
